==> gds-2.17.1.tar.gz: gds-2.17.1/Base/dict/gdsbase_linkdef.h <==
#ifdef __CINT__

#pragma link off all globals;
#pragma link off all classes;
#pragma link off all functions;

#pragma link C++ class Interval;
#pragma link C++ function operator +(const Interval&, const Interval&);
#pragma link C++ function operator -(const Interval&, const Interval&);
#pragma link C++ function operator *(const Interval&, double);
#pragma link C++ function operator *(double, const Interval&);
#pragma link C++ function operator /(const Interval&, const double);
#pragma link C++ function operator <<(std::ostream&, const Interval&);

#pragma link C++ class Time;
#pragma link C++ function operator +(const Time&, const Interval&);
#pragma link C++ function operator +(const Interval&, const Time&);
#pragma link C++ function operator -(const Time&, const Interval&);
#pragma link C++ function operator<<(std::ostream&, const Time&);
#pragma link C++ function Almost(const Time&, const Time&, unsigned long);
#pragma link C++ function Now();
#pragma link C++ function TimeStr(const Time&, char*, const char*);
#pragma link C++ function LocalStr(const Time&, char*, const char*);
#pragma link C++ function getUTC(const Time&);
#pragma link C++ function LeapS(const Time&);
#pragma link C++ function fromUTC(unsigned long);

#pragma link C++ class basicplx<float>;
#pragma link C++ function operator+(const fComplex&, const fComplex&);
#pragma link C++ function operator-(const fComplex&, const fComplex&);
#pragma link C++ function operator*(const fComplex&, const fComplex&);
#pragma link C++ function operator*(double, const fComplex&);
#pragma link C++ function operator*(const fComplex&, double);
#pragma link C++ function operator/(const fComplex&, const fComplex&);
#pragma link C++ function operator/(const fComplex&, double);
#pragma link C++ function operator<<(std::ostream&, const fComplex&);
#pragma link C++ function cc(const fComplex&);
#pragma link C++ function exp(const fComplex&);
#pragma link C++ function log(const fComplex&);
#pragma link C++ function Arg(const fComplex&);
#pragma link C++ function Real(const fComplex&);
#pragma link C++ function Imag(const fComplex&);
#pragma link C++ function abs(const fComplex&);
#pragma link C++ function sqrt(const fComplex&);

#pragma link C++ class basicplx<double>;
#pragma link C++ function operator+(const dComplex&, const dComplex&);
#pragma link C++ function operator-(const dComplex&, const dComplex&);
#pragma link C++ function operator*(const dComplex&, const dComplex&);
#pragma link C++ function operator*(double, const dComplex&);
#pragma link C++ function operator*(const dComplex&, double);
#pragma link C++ function operator/(const dComplex&, const dComplex&);
#pragma link C++ function operator/(const dComplex&, double);
#pragma link C++ function operator<<(std::ostream&, const dComplex&);
#pragma link C++ function cc(const dComplex&);
#pragma link C++ function exp(const dComplex&);
#pragma link C++ function log(const dComplex&);
#pragma link C++ function Arg(const dComplex&);
#pragma link C++ function Real(const dComplex&);
#pragma link C++ function Imag(const dComplex&);
#pragma link C++ function abs(const dComplex&);
#pragma link C++ function sqrt(const dComplex&);

#pragma link C++ function count_set_bits(bmask_t);
#pragma link C++ function highest_bit_set(bmask_t);
#pragma link C++ function is_power_of_2(bmask_t);
#pragma link C++ function make_mask(bcount_t);
#pragma link C++ function make_mask(bcount_t, bcount_t);
#pragma link C++ function lowest_bit_set(bmask_t);

#pragma link C++ function wfft(fComplex*, unsigned int, int);
#pragma link C++ function wfft(const float*, fComplex*, unsigned int);
#pragma link C++ function cffti(int, float*);
#pragma link C++ function cfftf(int, float*, float*);
#pragma link C++ function cfftp(int, float*);
#pragma link C++ function rffti(int, float*);
#pragma link C++ function rfftf(int, const float*, fComplex*, float*);
#pragma link C++ function wavefft(double*, double*, int, int, int, int);

#pragma link C++ function Rndm();
#pragma link C++ function RndmSeed(unsigned long);
#pragma link C++ function Rannor(double&, double&);
#pragma link C++ function Rannor();

#endif

==> gds-2.17.7.tar.gz: gds-2.17.7/Base/dict/gdsbase_linkdef.h <==
#ifdef __CINT__

#pragma link off all globals;
#pragma link off all classes;
#pragma link off all functions;

#pragma link C++ class Interval;
#pragma link C++ function operator +(const Interval&, const Interval&);
#pragma link C++ function operator -(const Interval&, const Interval&);
#pragma link C++ function operator *(const Interval&, double);
#pragma link C++ function operator *(double, const Interval&);
#pragma link C++ function operator /(const Interval&, const double);
#pragma link C++ function operator <<(std::ostream&, const Interval&);

#pragma link C++ class Time;
#pragma link C++ function operator +(const Time&, const Interval&);
#pragma link C++ function operator +(const Interval&, const Time&);
#pragma link C++ function operator -(const Time&, const Interval&);
#pragma link C++ function operator<<(std::ostream&, const Time&);
#pragma link C++ function Almost(const Time&, const Time&, unsigned long);
#pragma link C++ function Now();
#pragma link C++ function TimeStr(const Time&, char*, const char*);
#pragma link C++ function LocalStr(const Time&, char*, const char*);
#pragma link C++ function getUTC(const Time&);
#pragma link C++ function LeapS(const Time&);
#pragma link C++ function fromUTC(unsigned long);

#pragma link C++ class basicplx<float>;
#pragma link C++ function operator+(const fComplex&, const fComplex&);
#pragma link C++ function operator-(const fComplex&, const fComplex&);
#pragma link C++ function operator*(const fComplex&, const fComplex&);
#pragma link C++ function operator*(double, const fComplex&);
#pragma link C++ function operator*(const fComplex&, double);
#pragma link C++ function operator/(const fComplex&, const fComplex&);
#pragma link C++ function operator/(const fComplex&, double);
#pragma link C++ function operator<<(std::ostream&, const fComplex&);
#pragma link C++ function cc(const fComplex&);
#pragma link C++ function exp(const fComplex&);
#pragma link C++ function log(const fComplex&);
#pragma link C++ function Arg(const fComplex&);
#pragma link C++ function Real(const fComplex&);
#pragma link C++ function Imag(const fComplex&);
#pragma link C++ function abs(const fComplex&);
#pragma link C++ function sqrt(const fComplex&);

#pragma link C++ class basicplx<double>;
#pragma link C++ function operator+(const dComplex&, const dComplex&);
#pragma link C++ function operator-(const dComplex&, const dComplex&);
#pragma link C++ function operator*(const dComplex&, const dComplex&);
#pragma link C++ function operator*(double, const dComplex&);
#pragma link C++ function operator*(const dComplex&, double);
#pragma link C++ function operator/(const dComplex&, const dComplex&);
#pragma link C++ function operator/(const dComplex&, double);
#pragma link C++ function operator<<(std::ostream&, const dComplex&);
#pragma link C++ function cc(const dComplex&);
#pragma link C++ function exp(const dComplex&);
#pragma link C++ function log(const dComplex&);
#pragma link C++ function Arg(const dComplex&);
#pragma link C++ function Real(const dComplex&);
#pragma link C++ function Imag(const dComplex&);
#pragma link C++ function abs(const dComplex&);
#pragma link C++ function sqrt(const dComplex&);

#pragma link C++ function count_set_bits(bmask_t);
#pragma link C++ function highest_bit_set(bmask_t);
#pragma link C++ function is_power_of_2(bmask_t);
#pragma link C++ function make_mask(bcount_t);
#pragma link C++ function make_mask(bcount_t, bcount_t);
#pragma link C++ function lowest_bit_set(bmask_t);

#pragma link C++ function wfft(fComplex*, unsigned int, int);
#pragma link C++ function wfft(const float*, fComplex*, unsigned int);
#pragma link C++ function wfft(dComplex*, unsigned int, int);
#pragma link C++ function wfft(const float*, dComplex*, unsigned int);

#pragma link C++ function Rndm();
#pragma link C++ function RndmSeed(unsigned long);
#pragma link C++ function Rannor(double&, double&);
#pragma link C++ function Rannor();

#endif
